import setTip from '@/components/app/set-tip.vue';
import vueOfficeHeader from '@/components/vue-office-header';

import { getRequest } from '@/api/api';
import errMsg from '@/common/js/error';
import showMsg from '@/common/js/showmsg';
import { LunarDay } from '@shared/utils/getDate';
import dateFormat from '@/filters/index.js';
import moment from 'moment';

// 企业信息卡片数据集
const companyObj = {
  smallVersion: '',
  corpName: '',
  corpid: '',
  contactFlag: false,
  verifiedEndTime: '',
  corpIndustry: '',
  corpSubIndustry: '',
  corpUserMax: '',
  location: ''
};

const today = require('../../assets/data/today.png');
const login = require('../../assets/data/login.png');
const time = require('../../assets/data/time.png');
const people = require('../../assets/data/people.png');
const caseImage = require('../../assets/data/case.png');
const details = require('../../assets/data/details.svg');

export default {
  name: 'index',
  data() {
    return {
      checkShow: true,
      tipText: '请先完成商户初始化设置后，再进行其他操作',
      projectName: 'haoban-manage-web', // 当前项目名
      // contentHeight: '0px', // 页面内容高度
      collapseFlag: false, // 折叠参数
      showCustomDialog: false, // 自定义弹框显示标志
      customType: '', // 自定义弹框标志
      customTitle: '', //  自定义弹框标题
      wxEnterpriseId: localStorage.getItem('userInfos') ? JSON.parse(localStorage.getItem('userInfos')).wxEnterpriseId : '',
      // 购买应用
      purchaseApp: [],
      weeks: ['星期日', '星期一', '星期二', '星期三', '星期四', '星期五', '星期六'],
      // 未购买应用
      noPurchaseApp: [],
      versionData: {
        id: 1,
        smallVersion: '',
        corpName: '',
        date: new Date().getTime(),
        storeNum: 100,
        storeTotal: ''
      },
      helpList: [],
      companyObj: companyObj,
      countTotal: '',
      loading: false,
      caseImage: caseImage,
      details: details,
      selectEndDay: dateFormat.timeStampToYmd(new Date().getTime() - 24 * 3600 * 1000),
      selectTendDay: dateFormat.timeStampToYmd(new Date().getTime() - 24 * 3600 * 1000)
    };
  },
  filters: {
    formatTime(ns) {
      return moment(ns).format('YYYY/MM/DD HH:mm:ss');
    }
  },
  computed: {
    getLunarDay() {
      return LunarDay();
    }
  },
  methods: {
    /**
     * 获取好办使用情况
     */
    getLoginData() {
      const that = this;
      let para = {
        // enterpriseId: that.activeBrand,
        startDate: that.selectEndDay,
        endDate: that.selectEndDay
      };
      getRequest('/haoban-manage3-web/web/total-activation-data', para)
        .then(res => {
          let resData = res.data;
          if (resData.errorCode == 1) {
            const { toDayLoginClerkCnt, loginClerkCnt, avgLoginTimes, avgVisitTime, totalClerkCnt } = resData.result;

            // 好办使用情况数据
            that.countTotal = [
              {
                id: 1,
                title: '今日登录人数',
                num: toDayLoginClerkCnt || '0',
                icon: today,
                background: '#2F54EB',
                titleColor: 'rgba(255, 255, 255, 0.8)',
                numColor: '#FFFFFF',
                line: '1px solid rgba(255, 255, 255, 0.66)',
                iconBackground: 'linear-gradient(180deg, rgba(255, 255, 255, 0.18) 0%, rgba(255, 255, 255, 0) 100%)'
              },
              {
                id: 2,
                title: '昨日登录人数',
                num: loginClerkCnt || '0',
                icon: login,
                background: '#EBEFFE',
                titleColor: '#606266',
                numColor: '#303133',
                line: '1px solid #2F54EB',
                iconBackground: 'linear-gradient(180deg, rgba(92, 141, 247, 0.09) 0%, rgba(47, 84, 235, 0) 100%)'
              },
              {
                id: 3,
                title: '昨日人均登录次数',
                num: avgLoginTimes || '0',
                icon: login,
                background: '#FFFFFF',
                titleColor: '#606266',
                numColor: '#303133',
                line: '1px solid #2F54EB'
              },
              {
                id: 4,
                title: '昨日人均访问总时长',
                num: dateFormat.formatTime(parseInt(avgVisitTime) || 0),
                icon: time,
                background: '#FFFFFF',
                titleColor: '#606266',
                numColor: '#303133',
                line: '1px solid #2F54EB'
              },
              {
                id: 5,
                title: '员工总人数',
                num: totalClerkCnt || 0,
                icon: people,
                background: '#FFFFFF',
                titleColor: '#606266',
                numColor: '#303133',
                line: '1px solid #2F54EB'
              },
              {
                id: 6,
                title: '激活总人数',
                num: '后端接入',
                icon: people,
                tip: true,
                background: '#FFFFFF',
                titleColor: '#606266',
                numColor: '#303133',
                line: '1px solid #2F54EB'
              }
            ];
            return false;
          }
          errMsg.errorMsg(resData);
        })
        .catch(function(error) {
          that.$message.error({
            duration: 1000,
            message: error.message
          });
        });
    },
    /**
     * 获取企微基本信息
     */
    getData() {
      const that = this;
      that.loading = true;
      let para = {
        wxEnterpriseId: that.wxEnterpriseId
      };
      getRequest('/haoban-manage3-web/wxEnterprise-detail', para)
        .then(res => {
          let resData = res.data;
          if (resData.errorCode == 1) {
            that.companyObj = resData.result;
            this.openFlag = resData.result.agreeExternalUseridFlag === null ? 0 : resData.result.agreeExternalUseridFlag;
            that.loading = false;
            return false;
          }
          errMsg.errorMsg(resData);
        })
        .catch(function(error) {
          that.$message.error({
            duration: 1000,
            message: error.message
          });
        });
    },
    /**
     * 跳转更多 udesk
     */
    goUdesk() {
      window.open('https://notes.dingtalk.com/p/dy0mVP0g7lQPjz89/docs/dy0mV1QLjwErWX89');
    },

    /**
     * 帮助中心跳转
     */
    toRedirect(item) {
      if (!item.helpUrl) {
        return false;
      }
      window.open(item.helpUrl);
    },
    /**
     * 路由跳转
     */
    changeRoute(route) {
      this.$router.push(route);
    },

    /**
     * 跳转应用
     */
    toAppView(item) {
      const that = this;
      if (!item.applicationPath) {
        //无更多设置项，不可进入!
        showMsg.showmsg('无更多设置项，不可进入!', 'warning');
        return false;
      }
      that.changeRoute(`${item.applicationPath}`);
    },

    /**
     * 跳转购买
     */
    goShopping(item) {
      const that = this;
      that.changeRoute(`/`);
    },

    /**
     *  处理路由跳转
     */
    toRouterView(val) {
      const that = this;
      // 模拟检查数据,有两个参数
      that.$router.push({
        path: val.path
      });
    },

    /**
     * 启用停用应用
     */
    changeAppSwitch(e, item) {
      const that = this;
      that
        .$confirm(`确定要${e == true ? '启用' : '停用'}【${item.applicationName}】？`, '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          type: 'warning'
        })
        .then(() => {
          that.postAppSwitch(item);
        })
        .catch(() => {
          item.openFlag = false;
        });
    },
    postAppSwitch(item) {
      const that = this;
      let para = {
        wxEnterpriseId: that.wxEnterpriseId || localStorage.getItem('userInfos') ? JSON.parse(localStorage.getItem('userInfos')).wxEnterpriseId : '',
        applicationId: item.applicationId,
        openFlag: item.openFlag ? 1 : 0
      };
      getRequest('/haoban-manage3-web/open-or-close', para)
        .then(res => {
          let resData = res.data;
          if (resData.errorCode == 1) {
            showMsg.showmsg('启用成功', 'success');
            that.getAppData(1);
            return;
          }
          errMsg.errorMsg(resData);
        })
        .catch(function(error) {
          that.$message.error({
            duration: 1000,
            message: error.message
          });
        });
    },

    /**
     *   折叠事件
     */
    collapseTag(val) {
      const that = this;
      that.collapseFlag = val;
    },
    /**
     * 获取帮助中心
     */
    getHelpData() {
      const that = this;
      getRequest('/haoban-manage3-web/get-help-list', {})
        .then(res => {
          let resData = res.data;
          if (resData.errorCode == 1) {
            that.helpList = resData.result || [];
            return;
          }
          that.$message.error({
            duration: 1000,
            message: resData.message
          });
        })
        .catch(function(error) {
          that.$message.error({
            duration: 1000,
            message: error.message
          });
        });
    },

    /**
     *  获取数据概览
     */
    getAppData(type) {
      const that = this;
      let para = {
        wxEnterpriseId: that.wxEnterpriseId || localStorage.getItem('userInfos') ? JSON.parse(localStorage.getItem('userInfos')).wxEnterpriseId : '',
        type: type // 1已购买2未购买
      };
      getRequest('/haoban-manage3-web/application-open-close-list', para)
        .then(res => {
          let resData = res.data;
          if (resData.errorCode == 1) {
            resData.result.open.forEach(ele => {
              ele.openFlag = 1;
            });
            that.purchaseApp = JSON.parse(JSON.stringify(resData.result.open)) || [];

            resData.result.close.forEach(ele => {
              ele.openFlag = false;
            });
            that.noPurchaseApp = JSON.parse(JSON.stringify(resData.result.close)) || [];
            return;
          }
          errMsg.errorMsg(resData);
        })
        .catch(function(error) {
          that.$message.error({
            duration: 1000,
            message: error.message
          });
        });
    },
    /**
     *  获取绑定
     */
    getBindData() {
      const that = this;
      let para = {};
      getRequest('/haoban-manage3-web/has-bind-contract', para)
        .then(res => {
          let resData = res.data;
          if (resData.errorCode == 1) {
            if (!resData.result) {
              that.getBindUrl();
            }
            return;
          }
          errMsg.errorMsg(resData);
        })
        .catch(function(error) {
          that.$message.error({
            duration: 1000,
            message: error.message
          });
        });
    },
    /**
     *  获取绑定
     */
    getBindUrl() {
      const that = this;
      let para = {};
      getRequest('/haoban-manage3-web/get-auth-url', para)
        .then(res => {
          let resData = res.data;
          if (resData.errorCode == 1) {
            window.location.href = `${resData.result}`;
            return;
          }
          errMsg.errorMsg(resData);
        })
        .catch(function(error) {
          that.$message.error({
            duration: 1000,
            message: error.message
          });
        });
    },
    /**
     *  登录 --- api
     */
    toLogin() {
      const that = this;
      return new Promise((resolve, reject) => {
        let para = {};
        getRequest('/haoban-manage3-web/get-login-info', para)
          .then(res => {
            let resData = res.data;
            if (resData.errorCode == 1) {
              // localStorage.removeItem('userInfos');
              localStorage.setItem('userInfos', JSON.stringify(resData.result));
              resolve(resData.result.wxEnterpriseId);
              return;
            }
            errMsg.errorMsg(resData);
            resolve({
              wxEnterpriseId: ''
            });
          })
          .catch(function(error) {
            resolve({
              wxEnterpriseId: ''
            });
            that.$message.error({
              duration: 1000,
              message: error.message
            });
          });
      });
    },
    /**
     *  获取显示的提示
     */
    getTipData() {
      const that = this;
      let para = {};
      getRequest('/haoban-manage3-web/is-wx-enterprise-secret-set', para)
        .then(res => {
          let resData = res.data;
          if (resData.errorCode == 1) {
            that.checkShow = resData.result;
            return;
          }
          errMsg.errorMsg(resData);
        })
        .catch(function(error) {
          that.$message.error({
            duration: 1000,
            message: error.message
          });
        });
    },
    /**
     * 获取企业数据
     */
    getCompanyData() {
      const that = this;
      const para = {
        wxEnterpriseId: that.wxEnterpriseId
      };
      getRequest('/haoban-manage3-web/wxEnterprise-detail', para)
        .then(res => {
          let resData = res.data;
          if (resData.errorCode == 1) {
            that.versionData = resData.result;
            return false;
          }
          errMsg.errorMsg(resData);
        })
        .catch(function(error) {
          that.$message.error({
            duration: 1000,
            message: error.message
          });
        });
    }
  },
  async mounted() {
    const that = this;
    that.getData();
    that.getBindData();
    that.wxEnterpriseId = await that.toLogin();
    that.getAppData(1);
    that.getHelpData();
    that.getCompanyData();
    that.getLoginData();
  },
  components: {
    vueOfficeHeader,
    setTip
  }
};
